/*
|| This file is part of Pike. For copyright information see COPYRIGHT.
|| Pike is distributed under GPL, LGPL and MPL. See the file COPYING
|| for more information.
|| $Id: static_strings.h,v 1.3 2002/10/11 01:39:41 nilsson Exp $
*/

/* methods */

STRING(s_http_09,"HTTP/0.9");
STRING(s_http_10,"HTTP/1.0");
STRING(s_http_11,"HTTP/1.1");

/* headers */
STRING(s_user_agent,"user-agent");
STRING(s_if_modified_since,"if-modified-since");

/* variables */

STRING(s_not_query,"not_query");
STRING(s_query,"query");
STRING(s_prestate,"prestate");
STRING(s_time,"time");
STRING(s_my_fd,"my_fd");
STRING(s_prot,"prot");
STRING(s_method,"method");
STRING(s_rawurl,"rawurl");
STRING(s_raw,"raw");
STRING(s_data,"data");
STRING(s_remoteaddr,"remoteaddr");
STRING(s_headers,"headers");
STRING(s_pragma,"pragma");
STRING(s_client,"client");
STRING(s_referer,"referer");
STRING(s_since,"since");


STRING(s_variables,"variables");
STRING(s_rest_query,"rest_query");

/* To be implemented */

STRING(s_cookies,"cookies");
/* STRING(s_config,"config"); */

STRING(s_rawauth,"rawauth");
STRING(s_realauth,"realauth");
STRING(s_supports, "supports");
